mosquittoChat Docs! — mosquittoChat 1.0.0 documentation

# mosquittoChat Docs!

An MQTT protocol based Chat-Server/Chat-System using Mosquitto Broker, tornado as web server, sockjs in client(browser) side javascript library, sockjs-tornado as sockjs implementation on server side and paho-mqtt (mqtt python client).

Home Page : https://pypi.python.org/pypi/mosquittoChat

## Details

Author: | Anirban Roy Das
Email: | anirban.nick@gmail.com
Copyright(C): | 2016, Anirban Roy Das <anirban.nick@gmail.com>

Check `rabbitChat/LICENSE` file for full Copyright notice.

## Documentation:

- Overview
- Features
  - Technical Specs
  - Feature Specs
- Installation
  - Prerequisites
  - Install
- Usage
  - Mosquitto Server
  - mosquittoChat Application
- API
  - Main View
  - PubSub Module
- Full Reference in Nutshell
  - Documentation
  - Project Home Page
  - Details
  - Overview
  - Technical Specs
  - Features
  - Installation
  - Usage
  - Todo

# Indices and tables

- Index
- Module Index
- Search Page